@@ -7,14 +7,8 @@
 import datetime
 import re
 import logging
-try:     # Python 3.x
-    import urllib.parse
-    urlparse = urllib.parse.urlparse
-    parse_qs = urllib.parse.parse_qs
-except:  # Python 2.x
-    import urlparse as urlparse2
-    urlparse = urlparse2.urlparse
-    parse_qs = urlparse2.parse_qs
+
+from clitool.urlutils import urlparse, parse_qs
 
 
 # Probably default access log format for IPv4
@@ -53,6 +47,10 @@ def parse_request_path(s):
 
 
 class AccesslogParser(object):
+    """ Simple callable object which call regex match.
+    If given raw record matched access log format, returns extracted dict.
+    Otherwise, returns nothing with error logging.
+    """
 
     def __init__(self, logformat=LOG_FORMAT):
         self.logformat = logformat
@@ -64,6 +62,22 @@ class AccesslogParser(object):
         logging.error("Could not match given log format: %s", raw)
 
 
+def flatten_request_params(params):
+    """ Create case-less dictionary which have following features:
+    If length of values is one, treat it as string.
+    Otherwise, treat it as list.
+    """
+
+    results = {}
+    for k in params:
+        if len(params[k]) > 1:
+            logging.debug("Multiple values are found on '%s'.", k)
+            results[k.lower()] = params[k]
+        else:
+            results[k.lower()] = params[k][0]
+    return results
+
+
 def logentry(entry):
     """ Process mapped entry which has following keys:
 
@@ -77,7 +91,8 @@ def logentry(entry):
     is reported via logger. And retured entry includes error key.
 
     "request_query" will be added if "request_path" has query string.
-    Note that this is key/values mapping even if values have one element.
+    Note that this is basically key/values mapping. If a key has single value,
+    its value is extracted as single element.
 
     :param entry: regex parsed object
     :type entry: dict
@@ -87,7 +102,7 @@ def logentry(entry):
     path, query = parse_request_path(entry['request_path'])
     entry['request_path'] = path
     if query:
-        entry['request_query'] = query
+        entry['request_query'] = flatten_request_params(query)
     if entry['response_status']:
         s = int(entry['response_status'])
         if s >= 400:
@@ -111,6 +126,7 @@ def logparse(logformat=LOG_FORMAT, analyzer=None, *args, **kwargs):
     :type logformat: regex
     :param analyzer: function for each parsed object
     :type analyzer: callable
+    :param args: list of misc. callables
     :rtype: tuple of (statistics, key/value report)
     """
 
@@ -118,7 +134,7 @@ def logparse(logformat=LOG_FORMAT, analyzer=None, *args, **kwargs):
 
     reporter = SimpleDictReporter()
     stats = clistream(CliHandler, reporter,
-                AccesslogParser(logformat), logentry, analyzer, **kwargs)
+        AccesslogParser(logformat), logentry, analyzer, *args, **kwargs)
     return stats, reporter.report()
 
 
@@ -126,9 +142,9 @@ if __name__ == '__main__':
     from pprint import pprint
     from clitool.cli import parse_arguments
 
-    args = parse_arguments()
+    args = parse_arguments(files=dict(nargs='*'))
     stats, report = logparse(files=args.files, encoding=args.input_encoding)
-    pprint(stats)
-    pprint(report)
+    pprint(stats, stream=args.output)
+    pprint(report, stream=args.output)
 
 # vim: set et ts=4 sw=4 cindent fileencoding=utf-8 :
