@@ -80,12 +80,18 @@ def base_parser():
 def parse_arguments(*args, **kwargs):
     """ Parse command line arguments after setting basic options.
     If successfully parsed, set logging verbosity.
+
+    :param kwargs: keywords arguments to pass `add_argument` method.
+    :rtype: ArgumentParser object
     """
     parser = argparse.ArgumentParser(parents=[base_parser(), ])
 
-    parser.add_argument('files', nargs='*',
-                type=argparse.FileType('r'),
-                metavar="FILE")
+    for name in kwargs:
+        opts = kwargs[name]
+        if name == 'files':
+            opts['type'] = argparse.FileType('r')
+            opts['metavar'] = "FILE"
+        parser.add_argument(name, **opts)
 
     try:
         args = parser.parse_args()
@@ -127,7 +133,7 @@ def climain(func):
     def wrapper():
         spec = inspect.getargspec(func)
         args, varargs, keywords, defaults = spec
-        cliargs = parse_arguments()
+        cliargs = parse_arguments(files=dict(nargs='*'))
         kwargs = vars(cliargs)
         if keywords:
             return func(**kwargs)
@@ -157,6 +163,7 @@ def cliconfig(fp, env=None):
 
 
 if __name__ == '__main__':
+    args = parse_arguments()
     boilerplate = '''#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
@@ -180,6 +187,8 @@ if __name__ == '__main__':
 
 # vim: set et ts=4 sw=4 cindent fileencoding=utf-8 :
 '''.strip()
-    print(boilerplate)
+    args.output.write(boilerplate)
+    if not args.output.isatty():
+        os.chmod(args.output.name, 0o775)
 
 # vim: set et ts=4 sw=4 cindent fileencoding=utf-8 :
