@@ -30,6 +30,13 @@ from clitool import (
 
 
 class ConfigLoader(object):
+    """ Multi file type support config loader.
+    Available file types are:
+
+    * json
+    * yaml
+    * ini/cfg
+    """
 
     def __init__(self, fp, filetype=None):
         self.fp = fp
@@ -43,37 +50,60 @@ class ConfigLoader(object):
             logging.debug("Configfile=%s, extension=%s",
                 os.path.abspath(fname), extension)
             self.filetype = extension
+        self.config = None
 
     def _load(self):
+        if self.config is not None:
+            return
+        self.config = {}
         extension = self.filetype
         # XXX: separate each logic using dispatcher dict.
         if extension == ".json":
-            return json.load(self.fp)
+            self.config = json.load(self.fp)
         elif extension == ".py":
             # XXX: evaluate python script
-            return {}
-        elif extension == ".ini":
+            pass
+        elif extension == ".ini" or extension == ".cfg":
             parser = configparser.SafeConfigParser()
             parser.readfp(self.fp)
-            config = {}
             for s in parser.sections():
-                config[s] = dict(parser.items(s))
-            return config
+                self.config[s] = dict(parser.items(s))
         elif extension == ".yml" or extension == ".yaml":
             if YAML_ENABLED:
-                return yaml.load(self.fp)
+                self.config = yaml.load(self.fp)
             logging.error("PyYAML is not installed.")
-            return {}
         else:
             logging.warn('Unknown file type extension: %s', extension)
-            return {}
 
     def load(self, env=None):
+        """ Load a section values of given environment.
+
+        :param env: environment to load
+        :type env: string
+        :rtype: dict
+        """
+        self._load()
         e = env or \
             os.environ.get(RUNNING_MODE_ENVKEY, RUNNING_MODE_DEVELOPMENT)
-        config = self._load()
-        if e in config:
-            return config[e]
+        if e in self.config:
+            return self.config[e]
         logging.warn("Environment '%s' was not found.", e)
 
+    def flip(self):
+        """ Provide flip view to compare how key/value pair is defined in each
+        environment for administrative usage.
+
+        :rtype: dict
+        """
+        self._load()
+        groups = self.config.keys()
+        tabular = {}
+        for g in groups:
+            config = self.config[g]
+            for k in config:
+                r = tabular.get(k, {})
+                r[g] = config[k]
+                tabular[k] = r
+        return tabular
+
 # vim: set et ts=4 sw=4 cindent fileencoding=utf-8 :
